@@ -700,12 +700,6 @@ class VSTests(testing.TestCase):
         self.vs._get_package_items()
         self.assert_called_with('SoftLayer_Product_Package', 'getItems')
 
-    def test_get_package_items_errors(self):
-        mock = self.set_mock('SoftLayer_Product_Package', 'getAllObjects')
-        mock.return_value = []
-
-        self.assertRaises(ValueError, self.vs._get_package_items)
-
     def test_get_price_id_for_upgrade(self):
         package_items = self.vs._get_package_items()
 
@@ -754,9 +748,7 @@ class VSWaitReadyGoTests(testing.TestCase):
 
     def test_active_not_provisioned(self):
         # active transaction and no provision date should be false
-        self.guestObject.side_effect = [
-            {'activeTransaction': {'id': 1}},
-        ]
+        self.guestObject.return_value = {'activeTransaction': {'id': 1}}
         value = self.vs.wait_for_ready(1, 0)
         self.assertFalse(value)
 
@@ -769,18 +761,22 @@ class VSWaitReadyGoTests(testing.TestCase):
         value = self.vs.wait_for_ready(1, 1)
         self.assertTrue(value)
 
-    def test_active_provision_pending(self):
+    @mock.patch('time.sleep')
+    @mock.patch('time.time')
+    def test_active_provision_pending(self, _now, _sleep):
+        _now.side_effect = [0, 0, 1, 1, 2, 2]
         # active transaction and provision date
         # and pending should be false
-        self.guestObject.side_effect = [
-            {'activeTransaction': {'id': 1}, 'provisionDate': 'aaa'},
-        ]
-        value = self.vs.wait_for_ready(1, 0, pending=True)
+        self.guestObject.return_value = {'activeTransaction': {'id': 2}, 'provisionDate': 'aaa'}
+
+        value = self.vs.wait_for_ready(instance_id=1, limit=1, delay=1, pending=True)
+        _sleep.assert_has_calls([mock.call(0)])
         self.assertFalse(value)
 
     def test_active_reload(self):
         # actively running reload
         self.guestObject.side_effect = [
+            {'activeTransaction': {'id': 1}},
             {
                 'activeTransaction': {'id': 1},
                 'provisionDate': 'aaa',
@@ -792,46 +788,39 @@ class VSWaitReadyGoTests(testing.TestCase):
 
     def test_reload_no_pending(self):
         # reload complete, maintance transactions
-        self.guestObject.side_effect = [
-            {
-                'activeTransaction': {'id': 2},
-                'provisionDate': 'aaa',
-                'lastOperatingSystemReload': {'id': 1},
-            },
-        ]
+        self.guestObject.return_value = {
+            'activeTransaction': {'id': 2},
+            'provisionDate': 'aaa',
+            'lastOperatingSystemReload': {'id': 1},
+        }
+
         value = self.vs.wait_for_ready(1, 1)
         self.assertTrue(value)
 
-    def test_reload_pending(self):
+    @mock.patch('time.sleep')
+    @mock.patch('time.time')
+    def test_reload_pending(self, _now, _sleep):
+        _now.side_effect = [0, 0, 1, 1, 2, 2]
         # reload complete, pending maintance transactions
-        self.guestObject.side_effect = [
-            {
-                'activeTransaction': {'id': 2},
-                'provisionDate': 'aaa',
-                'lastOperatingSystemReload': {'id': 1},
-            },
-        ]
-        value = self.vs.wait_for_ready(1, 0, pending=True)
+        self.guestObject.return_value = {'activeTransaction': {'id': 2},
+                                         'provisionDate': 'aaa',
+                                         'lastOperatingSystemReload': {'id': 1}}
+        value = self.vs.wait_for_ready(instance_id=1, limit=1, delay=1, pending=True)
+        _sleep.assert_has_calls([mock.call(0)])
         self.assertFalse(value)
 
     @mock.patch('time.sleep')
     def test_ready_iter_once_incomplete(self, _sleep):
-        self.guestObject = self.client['Virtual_Guest'].getObject
-
         # no iteration, false
-        self.guestObject.side_effect = [
-            {'activeTransaction': {'id': 1}},
-        ]
+        self.guestObject.return_value = {'activeTransaction': {'id': 1}}
         value = self.vs.wait_for_ready(1, 0, delay=1)
         self.assertFalse(value)
-        self.assertFalse(_sleep.called)
+        _sleep.assert_has_calls([mock.call(0)])
 
     @mock.patch('time.sleep')
     def test_iter_once_complete(self, _sleep):
         # no iteration, true
-        self.guestObject.side_effect = [
-            {'provisionDate': 'aaa'},
-        ]
+        self.guestObject.return_value = {'provisionDate': 'aaa'}
         value = self.vs.wait_for_ready(1, 1, delay=1)
         self.assertTrue(value)
         self.assertFalse(_sleep.called)
@@ -859,15 +848,16 @@ class VSWaitReadyGoTests(testing.TestCase):
     def test_iter_two_incomplete(self, _sleep, _time):
         # test 2 iterations, with no matches
         self.guestObject.side_effect = [
+            {'activeTransaction': {'id': 1}},
             {'activeTransaction': {'id': 1}},
             {'activeTransaction': {'id': 1}},
             {'provisionDate': 'aaa'}
         ]
         # logging calls time.time as of pytest3.3, not sure if there is a better way of getting around that.
-        _time.side_effect = [0, 0, 1, 1, 2, 2, 2]
+        _time.side_effect = [0, 1, 2, 3, 4, 5, 6]
         value = self.vs.wait_for_ready(1, 2, delay=1)
         self.assertFalse(value)
-        _sleep.assert_called_once_with(1)
+        _sleep.assert_has_calls([mock.call(1), mock.call(0)])
         self.guestObject.assert_has_calls([
             mock.call(id=1, mask=mock.ANY),
             mock.call(id=1, mask=mock.ANY),
@@ -886,22 +876,22 @@ class VSWaitReadyGoTests(testing.TestCase):
 
         _sleep.assert_has_calls([mock.call(10)])
 
-    @mock.patch('SoftLayer.managers.vs.VSManager.get_instance')
-    @mock.patch('random.randint')
+    @mock.patch('SoftLayer.decoration.sleep')
+    @mock.patch('SoftLayer.transports.FixtureTransport.__call__')
     @mock.patch('time.time')
     @mock.patch('time.sleep')
-    def test_exception_from_api(self, _sleep, _time, _random, _vs):
+    def test_exception_from_api(self, _sleep, _time, _vs, _dsleep):
         """Tests escalating scale back when an excaption is thrown"""
-        self.guestObject.return_value = {'activeTransaction': {'id': 1}}
-        _vs.side_effect = exceptions.TransportError(104, "Its broken")
+        _dsleep.return_value = False
+
+        self.guestObject.side_effect = [
+            exceptions.TransportError(104, "Its broken"),
+            {'activeTransaction': {'id': 1}},
+            {'provisionDate': 'aaa'}
+        ]
         # logging calls time.time as of pytest3.3, not sure if there is a better way of getting around that.
-        _time.side_effect = [0, 0, 0, 0, 2, 2, 2, 6, 6, 6, 14, 14, 14, 20, 20, 20, 100, 100, 100]
-        _random.side_effect = [0, 0, 0, 0, 0]
+        _time.side_effect = [0, 1, 2, 3, 4]
         value = self.vs.wait_for_ready(1, 20, delay=1)
-        _sleep.assert_has_calls([
-            mock.call(2),
-            mock.call(4),
-            mock.call(8),
-            mock.call(6)
-        ])
-        self.assertFalse(value)
+        _sleep.assert_called_once()
+        _dsleep.assert_called_once()
+        self.assertTrue(value)
